import unittest
from ExtendedDiagramIcons.module2 import ok

class TestCase(unittest.TestCase):
    def test_ok(self):
        print(ok())

if __name__ == "__main__":
    unittest.main()
    print(Test.assetEqual)


from ...common import CustomNode

class octopusDeployProgram(CustomNode):
    _icon = "octopus_deploy_icon.png"

class octopusDeployPipeline(CustomNode):
    _icon = "pipeline_icon.png"

class octopusDeployServerNode(CustomNode):
    _icon = "octopus_server_node_icon.png"

class octopusDeployWorkerNode(CustomNode):
    _icon = "octopus_worker_node_icon.png"

class octopusDeployWorkerPool(CustomNode):
    _icon = "octopus_worker_pool_icon.png"

class octpusDeployRelease(CustomNode):
    _icon = "release_icon.png"


from diagrams import Diagram
from ExtendedDiagramIcons.onprem.cd.octopusDeploy import octopusDeployProgram
from ExtendedDiagramIcons.onprem.cd.octopusDeploy import octopusDeployPipeline
from ExtendedDiagramIcons.onprem.cd.octopusDeploy import octopusDeployServerNode
from ExtendedDiagramIcons.onprem.cd.octopusDeploy import octopusDeployWorkerNode
from ExtendedDiagramIcons.onprem.cd.octopusDeploy import octopusDeployWorkerPool
from ExtendedDiagramIcons.onprem.cd.octopusDeploy import octpusDeployRelease
from ExtendedDiagramIcons.generic import softwareEngineer
from ExtendedDiagramIcons.generic import JIRA
from ExtendedDiagramIcons.generic import GitHub
from ExtendedDiagramIcons.generic import ReportPortal

def octopusDeploy_icon(val):
    return octopusDeployProgram(val)

def octopusDeployPipeline_icon(val):
    return octopusDeployPipeline(val)

def octopusDeployServerNode_icon(val):
    return octopusDeployServerNode(val)

def octopusDeployWorkerNode_icon(val):
    return octopusDeployServerNode(val)

def octopusDeployWorkerPool_icon(val):
    return octopusDeployServerNode(val)

def octpusDeployRelease_icon(val):
    return octpusDeployRelease(val)

def softwareEngineer_icon(val):
    return softwareEngineer(val)

def JIRA_icon(val):
    return JIRA(val)

def GitHub_icon(val):
    return GitHub(val)

def ReportPortal_icon(val):
    return ReportPortal(val)


from .common import CustomNode

class softwareEngineer(CustomNode):
    _icon = "software_engineer_icon.png"

class JIRA(CustomNode):
    _icon = "jira_icon.png"

class GitHub(CustomNode):
    _icon = "github_icon.png"

class CRIMTools(CustomNode):
    _icon = "crim_tools_icon.png"

class ReportPortal(CustomNode):
    _icon = "report_portal_icon.jpg"


import unittest
from diagrams import Diagram, Cluster
from ExtendedDiagramIcons.module1 import octopusDeploy_icon
from ExtendedDiagramIcons.module1 import octopusDeployPipeline_icon
from ExtendedDiagramIcons.module1 import octopusDeployServerNode_icon
from ExtendedDiagramIcons.module1 import octopusDeployWorkerNode_icon
from ExtendedDiagramIcons.module1 import octopusDeployWorkerPool_icon
from ExtendedDiagramIcons.module1 import octpusDeployRelease_icon
from ExtendedDiagramIcons.module1 import softwareEngineer_icon
from ExtendedDiagramIcons.module1 import JIRA_icon
from ExtendedDiagramIcons.module1 import CRIM_icon
from ExtendedDiagramIcons.module1 import GitHub_icon
from ExtendedDiagramIcons.module1 import CRIMTools_icon
from ExtendedDiagramIcons.module1 import ReportPortal_icon

class TestCase(unittest.TestCase):
    def test_icon_map(self):
        with Diagram("All Icons", show=False):
            with Cluster("onprem"):
                with Cluster("cd"):
                    print(octopusDeploy_icon("Octopus Deploy"))
                    octopusDeployPipeline_icon("Octopus Deploy Pipeline")
                    octopusDeployServerNode_icon("Octopus Deploy Server Node")
                    octopusDeployWorkerNode_icon("Octopus Deploy Worker Node")
                    octopusDeployWorkerPool_icon("Octopus Deploy Worker Pool")
                    octpusDeployRelease_icon("Octopus Deploy Release")
            with Cluster("generic"):
                softwareEngineer_icon("Software Engineer")
                JIRA_icon("JIRA")
                CRIM_icon("CRIM Team")
                GitHub_icon("GitHub")
                CRIMTools_icon("CRIM Tools")
                ReportPortal_icon("Report Portal")

if __name__ == "__main__":
    unittest.main()
    print(Test.assetEqual)


import os
from setuptools import setup, find_packages

def get_version():
    basedir = os.path.dirname(__file__)
    with open(os.path.join(basedir, "ExtendedDiagramIcons/__init__.py")) as f:
        locals = {}
        exec(f.read(), locals)
        return locals["__version__"]

setup(
    name="ExtendedDiagramIcons",
    version=get_version(),
    author="Joshua Duma",
    author_email="joshua.duma@trader.ca",
    description="This is intended to be used in a project that uses the diagrams (diagrams as code) python package as an extention of the icons.",
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    url="",
    include_package_data=True,
    packages=find_packages(),
    install_requires=[
        "diagrams>=0.23.4"
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)